import Image from '@theme/IdealImage';

# A/B Test LLMs - Tutorial!

Move freely from OpenAI to other models using LiteLLM. In this tutorial, we'll go through how to A/B test between OpenAI, Claude and TogetherAI using LiteLLM.

Resources: 
* [Code](https://github.com/BerriAI/litellm/tree/main/cookbook/llm-ab-test-server)
* [Sample Dashboard](https://lite-llm-abtest-ui.vercel.app/ishaan_discord@berri.ai)

# Code Walkthrough
This is the main piece of code that we'll write to handle our A/B test logic. We'll cover specific details in [Setup](#setup)
### Define LLMs with their A/B test ratios
In main.py set select the LLMs you want to AB test in `llm_dict` (and remember to set their API keys in the .env)!

We support 5+ providers and 100+ LLMs: https://docs.litellm.ai/docs/completion/supported

```python
llm_dict = {
    "gpt-4": 0.2,
    "together_ai/togethercomputer/llama-2-70b-chat": 0.4,
    "claude-2": 0.2,
    "claude-1.2": 0.2
}
```

### Select LLM + Make Completion call
Use weighted selection, and call the model using litellm.completion
```python
from litellm import completion
selected_llm = random.choices(list(llm_dict.keys()), weights=list(llm_dict.values()))[0]

response = completion(model=selected_model, messages=[{ "content": "Hello, how are you?","role": "user"}])

```

### Viewing Logs, Feedback 
In order to view logs set `litellm.token=<your-email>`
```python
import litellm
litellm.token='ishaan_discord@berri.ai'
```

Here is what your logs dashboard looks like:
<Image img={require('../../img/ab_test_logs.png')} />

Your logs will be available at: 
https://lite-llm-abtest-nckmhi7ue-clerkieai.vercel.app/your-token

### Live Demo UI
👉https://lite-llm-abtest-nckmhi7ue-clerkieai.vercel.app/ishaan_discord@berri.ai

## Viewing Responses + Custom Scores 
LiteLLM UI allows you to view responses and set custom scores for each response

## Setup

### Install LiteLLM
```
pip install litellm
```

### Clone LiteLLM Git Repo
```
git clone https://github.com/BerriAI/litellm/
```

### Navigate to LiteLLM-A/B Test Server
```
cd litellm/cookbook/llm-ab-test-server
```


### Run the Server 
```
python3 main.py
```

## Testing our Server
The server follows the Input/Output format set by the OpenAI Chat Completions API
Here is an example request made the LiteLLM Server

### Python
```python
import requests
import json

url = "http://localhost:5000/chat/completions"

payload = json.dumps({
  "messages": [
    {
      "content": "who is CTO of litellm",
      "role": "user"
    }
  ]
})
headers = {
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)

print(response.text)

```

### Curl Command
```
curl --location 'http://localhost:5000/chat/completions' \
--header 'Content-Type: application/json' \
--data '{
    "messages": [
                    { 
                        "content": "who is CTO of litellm",
                        "role": "user"
                    }
                ]
    
}
'
```




